[SCM] Samba Shared Repository - branch master updated - tevent-0-9-8-354-g94d83b6

Günther Deschner gd at samba.org
Wed Sep 16 01:11:11 MDT 2009


The branch, master has been updated
       via  94d83b62c943837b2b3a0ca8cc83e6d41f8e8733 (commit)
       via  37bc80645358fc2e2eba465b451080b0d328c722 (commit)
      from  c5c04fcf90849d31ff4d0343dedec2c097823a7e (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit 94d83b62c943837b2b3a0ca8cc83e6d41f8e8733
Author: Günther Deschner <gd at samba.org>
Date:   Wed Sep 16 08:55:17 2009 +0200

    s3-ntlmssp: add missing prototype.
    
    Guenther

commit 37bc80645358fc2e2eba465b451080b0d328c722
Author: Günther Deschner <gd at samba.org>
Date:   Wed Sep 16 08:54:31 2009 +0200

    s3-dcerpc: remove more obsolete or duplicate headers.
    
    Guenther

-----------------------------------------------------------------------

Summary of changes:
 librpc/gen_ndr/ndr_ntlmssp.c      |    4 +-
 librpc/gen_ndr/ndr_ntlmssp.h      |    1 +
 source3/include/proto.h           |    2 +-
 source3/include/rpc_dce.h         |   44 +---------------------------
 source3/rpc_client/cli_pipe.c     |   44 ++++++++++++++--------------
 source3/rpc_parse/parse_rpc.c     |    2 +-
 source3/rpc_server/srv_pipe.c     |   30 +++++++++---------
 source3/rpc_server/srv_pipe_hnd.c |   58 ++++++++++++++++++------------------
 8 files changed, 72 insertions(+), 113 deletions(-)


Changeset truncated at 500 lines:

diff --git a/librpc/gen_ndr/ndr_ntlmssp.c b/librpc/gen_ndr/ndr_ntlmssp.c
index 2b4e70e..8e379bf 100644
--- a/librpc/gen_ndr/ndr_ntlmssp.c
+++ b/librpc/gen_ndr/ndr_ntlmssp.c
@@ -2279,7 +2279,7 @@ static const struct ndr_interface_call ntlmssp_calls[] = {
 };
 
 static const char * const ntlmssp_endpoint_strings[] = {
-	"ncacn_np:[\\pipe\\ntlmssp]",
+	"ncacn_np:[\\pipe\\ntlmssp]", 
 };
 
 static const struct ndr_interface_string_array ntlmssp_endpoints = {
@@ -2288,7 +2288,7 @@ static const struct ndr_interface_string_array ntlmssp_endpoints = {
 };
 
 static const char * const ntlmssp_authservice_strings[] = {
-	"host",
+	"host", 
 };
 
 static const struct ndr_interface_string_array ntlmssp_authservices = {
diff --git a/librpc/gen_ndr/ndr_ntlmssp.h b/librpc/gen_ndr/ndr_ntlmssp.h
index de31c6c..ab095d1 100644
--- a/librpc/gen_ndr/ndr_ntlmssp.h
+++ b/librpc/gen_ndr/ndr_ntlmssp.h
@@ -50,6 +50,7 @@ void ndr_print_LM_RESPONSE(struct ndr_print *ndr, const char *name, const struct
 enum ndr_err_code ndr_push_LMv2_RESPONSE(struct ndr_push *ndr, int ndr_flags, const struct LMv2_RESPONSE *r);
 enum ndr_err_code ndr_pull_LMv2_RESPONSE(struct ndr_pull *ndr, int ndr_flags, struct LMv2_RESPONSE *r);
 void ndr_print_LMv2_RESPONSE(struct ndr_print *ndr, const char *name, const struct LMv2_RESPONSE *r);
+void ndr_print_ntlmssp_LM_RESPONSE(struct ndr_print *ndr, const char *name, const union ntlmssp_LM_RESPONSE *r);
 enum ndr_err_code ndr_push_NTLM_RESPONSE(struct ndr_push *ndr, int ndr_flags, const struct NTLM_RESPONSE *r);
 enum ndr_err_code ndr_pull_NTLM_RESPONSE(struct ndr_pull *ndr, int ndr_flags, struct NTLM_RESPONSE *r);
 void ndr_print_NTLM_RESPONSE(struct ndr_print *ndr, const char *name, const struct NTLM_RESPONSE *r);
diff --git a/source3/include/proto.h b/source3/include/proto.h
index 8af6dba..007ee9f 100644
--- a/source3/include/proto.h
+++ b/source3/include/proto.h
@@ -5712,7 +5712,7 @@ bool prs_data_blob(prs_struct *prs, DATA_BLOB *blob, TALLOC_CTX *mem_ctx);
 /* The following definitions come from rpc_parse/parse_rpc.c  */
 
 const char *get_pipe_name_from_iface(const struct ndr_syntax_id *interface);
-void init_rpc_hdr(RPC_HDR *hdr, enum RPC_PKT_TYPE pkt_type, uint8 flags,
+void init_rpc_hdr(RPC_HDR *hdr, enum dcerpc_pkt_type pkt_type, uint8 flags,
 				uint32 call_id, int data_len, int auth_len);
 bool smb_io_rpc_hdr(const char *desc,  RPC_HDR *rpc, prs_struct *ps, int depth);
 void init_rpc_context(RPC_CONTEXT *rpc_ctx, uint16 context_id,
diff --git a/source3/include/rpc_dce.h b/source3/include/rpc_dce.h
index fc2d880..3fd833c 100644
--- a/source3/include/rpc_dce.h
+++ b/source3/include/rpc_dce.h
@@ -22,49 +22,7 @@
 #ifndef _DCE_RPC_H /* _DCE_RPC_H */
 #define _DCE_RPC_H 
 
-/* DCE/RPC packet types */
-
-enum RPC_PKT_TYPE {
-	RPC_REQUEST  = 0x00, 	/* Ordinary request. */
-	RPC_PING     = 0x01,	/* Connectionless is server alive ? */
-	RPC_RESPONSE = 0x02,	/* Ordinary reply. */
-	RPC_FAULT    = 0x03,	/* Fault in processing of call. */
-	RPC_WORKING  = 0x04,	/* Connectionless reply to a ping when server busy. */
-	RPC_NOCALL   = 0x05,	/* Connectionless reply to a ping when server has lost part of clients call. */
-	RPC_REJECT   = 0x06,	/* Refuse a request with a code. */
-	RPC_ACK      = 0x07,	/* Connectionless client to server code. */
-	RPC_CL_CANCEL= 0x08,	/* Connectionless cancel. */
-	RPC_FACK     = 0x09,	/* Connectionless fragment ack. Both client and server send. */
-	RPC_CANCEL_ACK = 0x0A,	/* Server ACK to client cancel request. */
-	RPC_BIND     = 0x0B,	/* Bind to interface. */
-	RPC_BINDACK  = 0x0C,	/* Server ack of bind. */
-	RPC_BINDNACK = 0x0D,	/* Server nack of bind. */
-	RPC_ALTCONT  = 0x0E,	/* Alter auth. */
-	RPC_ALTCONTRESP = 0x0F,	/* Reply to alter auth. */
-	RPC_AUTH3    = 0x10, 	/* not the real name!  this is undocumented! */
-	RPC_SHUTDOWN = 0x11,	/* Server to client request to shutdown. */
-	RPC_CO_CANCEL= 0x12,	/* Connection-oriented cancel request. */
-	RPC_ORPHANED = 0x13	/* Client telling server it's aborting a partially sent request or telling
-				   server to stop sending replies. */
-};
-
-/* DCE/RPC flags */
-#define RPC_FLG_FIRST 0x01
-#define RPC_FLG_LAST  0x02
-#define RPC_FLG_NOCALL 0x20
-
-/* Netlogon schannel auth type and level */
-#define SCHANNEL_SIGN_SIGNATURE { 0x77, 0x00, 0xff, 0xff, 0xff, 0xff, 0x00, 0x00 }
-#define SCHANNEL_SEAL_SIGNATURE { 0x77, 0x00, 0x7a, 0x00, 0xff, 0xff, 0x00, 0x00 }
-
 #define RPC_AUTH_SCHANNEL_SIGN_OR_SEAL_CHK_LEN 	0x20
-#define RPC_AUTH_SCHANNEL_SIGN_ONLY_CHK_LEN 	0x18
-
-
-enum schannel_direction {
-	SENDER_IS_INITIATOR,
-	SENDER_IS_ACCEPTOR
-};
 
 /* Maximum size of the signing data in a fragment. */
 #define RPC_MAX_SIGN_SIZE 0x38 /* 56 */
@@ -79,7 +37,7 @@ enum schannel_direction {
 typedef struct rpc_hdr_info {
 	uint8  major; /* 5 - RPC major version */
 	uint8  minor; /* 0 - RPC minor version */
-	uint8  pkt_type; /* RPC_PKT_TYPE - RPC response packet */
+	uint8  pkt_type; /* dcerpc_pkt_type - RPC response packet */
 	uint8  flags; /* DCE/RPC flags */
 	uint8  pack_type[4]; /* 0x1000 0000 - little-endian packed data representation */
 	uint16 frag_len; /* fragment length - data size (bytes) inc header and tail. */
diff --git a/source3/rpc_client/cli_pipe.c b/source3/rpc_client/cli_pipe.c
index 133334b..393c726 100644
--- a/source3/rpc_client/cli_pipe.c
+++ b/source3/rpc_client/cli_pipe.c
@@ -872,14 +872,14 @@ static NTSTATUS cli_pipe_validate_current_pdu(struct rpc_pipe_client *cli, RPC_H
 
 	/* Ensure we have the correct type. */
 	switch (prhdr->pkt_type) {
-		case RPC_ALTCONTRESP:
-		case RPC_BINDACK:
+		case DCERPC_PKT_ALTER_RESP:
+		case DCERPC_PKT_BIND_ACK:
 
 			/* Alter context and bind ack share the same packet definitions. */
 			break;
 
 
-		case RPC_RESPONSE:
+		case DCERPC_PKT_RESPONSE:
 		{
 			RPC_HDR_RESP rhdr_resp;
 			uint8 ss_padding_len = 0;
@@ -935,14 +935,14 @@ static NTSTATUS cli_pipe_validate_current_pdu(struct rpc_pipe_client *cli, RPC_H
 			break;
 		}
 
-		case RPC_BINDNACK:
+		case DCERPC_PKT_BIND_NAK:
 			DEBUG(1, ("cli_pipe_validate_current_pdu: Bind NACK "
 				  "received from %s!\n",
 				  rpccli_pipe_txt(debug_ctx(), cli)));
 			/* Use this for now... */
 			return NT_STATUS_NETWORK_ACCESS_DENIED;
 
-		case RPC_FAULT:
+		case DCERPC_PKT_FAULT:
 		{
 			RPC_HDR_RESP rhdr_resp;
 			RPC_HDR_FAULT fault_resp;
@@ -989,10 +989,10 @@ static NTSTATUS cli_pipe_validate_current_pdu(struct rpc_pipe_client *cli, RPC_H
 	   data before now as we may have needed to do cryptographic actions on
 	   it before. */
 
-	if ((prhdr->pkt_type == RPC_BINDACK) && !(prhdr->flags & RPC_FLG_LAST)) {
+	if ((prhdr->pkt_type == DCERPC_PKT_BIND_ACK) && !(prhdr->flags & DCERPC_PFC_FLAG_LAST)) {
 		DEBUG(5,("cli_pipe_validate_current_pdu: bug in server (AS/U?), "
 			"setting fragment first/last ON.\n"));
-		prhdr->flags |= RPC_FLG_FIRST|RPC_FLG_LAST;
+		prhdr->flags |= DCERPC_PFC_FLAG_FIRST|DCERPC_PFC_FLAG_LAST;
 	}
 
 	return NT_STATUS_OK;
@@ -1392,7 +1392,7 @@ static void rpc_api_pipe_got_pdu(struct tevent_req *subreq)
 		return;
 	}
 
-	if ((state->rhdr.flags & RPC_FLG_FIRST)
+	if ((state->rhdr.flags & DCERPC_PFC_FLAG_FIRST)
 	    && (state->rhdr.pack_type[0] == 0)) {
 		/*
 		 * Set the data type correctly for big-endian data on the
@@ -1433,7 +1433,7 @@ static void rpc_api_pipe_got_pdu(struct tevent_req *subreq)
 		return;
 	}
 
-	if (state->rhdr.flags & RPC_FLG_LAST) {
+	if (state->rhdr.flags & DCERPC_PFC_FLAG_LAST) {
 		DEBUG(10,("rpc_api_pipe: %s returned %u bytes.\n",
 			  rpccli_pipe_txt(debug_ctx(), state->cli),
 			  (unsigned)prs_data_size(&state->incoming_pdu)));
@@ -1679,7 +1679,7 @@ static NTSTATUS create_schannel_auth_rpc_bind_req( struct rpc_pipe_client *cli,
  Creates the internals of a DCE/RPC bind request or alter context PDU.
  ********************************************************************/
 
-static NTSTATUS create_bind_or_alt_ctx_internal(enum RPC_PKT_TYPE pkt_type,
+static NTSTATUS create_bind_or_alt_ctx_internal(enum dcerpc_pkt_type pkt_type,
 						prs_struct *rpc_out, 
 						uint32 rpc_call_id,
 						const struct ndr_syntax_id *abstract,
@@ -1714,7 +1714,7 @@ static NTSTATUS create_bind_or_alt_ctx_internal(enum RPC_PKT_TYPE pkt_type,
 	}
 
 	/* Create the request RPC_HDR */
-	init_rpc_hdr(&hdr, pkt_type, RPC_FLG_FIRST|RPC_FLG_LAST, rpc_call_id, frag_len, auth_len);
+	init_rpc_hdr(&hdr, pkt_type, DCERPC_PFC_FLAG_FIRST|DCERPC_PFC_FLAG_LAST, rpc_call_id, frag_len, auth_len);
 
 	/* Marshall the RPC header */
 	if(!smb_io_rpc_hdr("hdr"   , &hdr, rpc_out, 0)) {
@@ -1818,7 +1818,7 @@ static NTSTATUS create_rpc_bind_req(struct rpc_pipe_client *cli,
 			return NT_STATUS_INVALID_INFO_CLASS;
 	}
 
-	ret = create_bind_or_alt_ctx_internal(RPC_BIND,
+	ret = create_bind_or_alt_ctx_internal(DCERPC_PKT_BIND,
 						rpc_out, 
 						rpc_call_id,
 						abstract,
@@ -2126,7 +2126,7 @@ struct tevent_req *rpc_api_pipe_req_send(TALLOC_CTX *mem_ctx,
 	if (is_last_frag) {
 		subreq = rpc_api_pipe_send(state, ev, state->cli,
 					   &state->outgoing_frag,
-					   RPC_RESPONSE);
+					   DCERPC_PKT_RESPONSE);
 		if (subreq == NULL) {
 			goto fail;
 		}
@@ -2172,11 +2172,11 @@ static NTSTATUS prepare_next_frag(struct rpc_api_pipe_req_state *state,
 		state->cli, data_left, &frag_len, &auth_len, &ss_padding);
 
 	if (state->req_data_sent == 0) {
-		flags = RPC_FLG_FIRST;
+		flags = DCERPC_PFC_FLAG_FIRST;
 	}
 
 	if (data_sent_thistime == data_left) {
-		flags |= RPC_FLG_LAST;
+		flags |= DCERPC_PFC_FLAG_LAST;
 	}
 
 	if (!prs_set_offset(&state->outgoing_frag, 0)) {
@@ -2184,7 +2184,7 @@ static NTSTATUS prepare_next_frag(struct rpc_api_pipe_req_state *state,
 	}
 
 	/* Create and marshall the header and request header. */
-	init_rpc_hdr(&hdr, RPC_REQUEST, flags, state->call_id, frag_len,
+	init_rpc_hdr(&hdr, DCERPC_PKT_REQUEST, flags, state->call_id, frag_len,
 		     auth_len);
 
 	if (!smb_io_rpc_hdr("hdr    ", &hdr, &state->outgoing_frag, 0)) {
@@ -2232,7 +2232,7 @@ static NTSTATUS prepare_next_frag(struct rpc_api_pipe_req_state *state,
 	}
 
 	state->req_data_sent += data_sent_thistime;
-	*is_last_frag = ((flags & RPC_FLG_LAST) != 0);
+	*is_last_frag = ((flags & DCERPC_PFC_FLAG_LAST) != 0);
 
 	return status;
 }
@@ -2262,7 +2262,7 @@ static void rpc_api_pipe_req_write_done(struct tevent_req *subreq)
 	if (is_last_frag) {
 		subreq = rpc_api_pipe_send(state, state->ev, state->cli,
 					   &state->outgoing_frag,
-					   RPC_RESPONSE);
+					   DCERPC_PKT_RESPONSE);
 		if (tevent_req_nomem(subreq, req)) {
 			return;
 		}
@@ -2419,7 +2419,7 @@ static NTSTATUS create_rpc_bind_auth3(struct rpc_pipe_client *cli,
 	uint32 pad = 0;
 
 	/* Create the request RPC_HDR */
-	init_rpc_hdr(&hdr, RPC_AUTH3, RPC_FLG_FIRST|RPC_FLG_LAST, rpc_call_id,
+	init_rpc_hdr(&hdr, DCERPC_PKT_AUTH3, DCERPC_PFC_FLAG_FIRST|DCERPC_PFC_FLAG_LAST, rpc_call_id,
 		     RPC_HEADER_LEN + 4 /* pad */ + RPC_HDR_AUTH_LEN + pauth_blob->length,
 		     pauth_blob->length );
 
@@ -2492,7 +2492,7 @@ static NTSTATUS create_rpc_alter_context(uint32 rpc_call_id,
 		}
 	}
 
-	ret = create_bind_or_alt_ctx_internal(RPC_ALTCONT,
+	ret = create_bind_or_alt_ctx_internal(DCERPC_PKT_ALTER,
 						rpc_out, 
 						rpc_call_id,
 						abstract,
@@ -2573,7 +2573,7 @@ struct tevent_req *rpc_pipe_bind_send(TALLOC_CTX *mem_ctx,
 	}
 
 	subreq = rpc_api_pipe_send(state, ev, cli, &state->rpc_out,
-				   RPC_BINDACK);
+				   DCERPC_PKT_BIND_ACK);
 	if (subreq == NULL) {
 		goto fail;
 	}
@@ -2841,7 +2841,7 @@ static NTSTATUS rpc_finish_spnego_ntlmssp_bind_send(struct tevent_req *req,
 	}
 
 	subreq = rpc_api_pipe_send(state, state->ev, state->cli,
-				   &state->rpc_out, RPC_ALTCONTRESP);
+				   &state->rpc_out, DCERPC_PKT_ALTER_RESP);
 	if (subreq == NULL) {
 		return NT_STATUS_NO_MEMORY;
 	}
diff --git a/source3/rpc_parse/parse_rpc.c b/source3/rpc_parse/parse_rpc.c
index eb568b6..f720de3 100644
--- a/source3/rpc_parse/parse_rpc.c
+++ b/source3/rpc_parse/parse_rpc.c
@@ -29,7 +29,7 @@
  Inits an RPC_HDR structure.
 ********************************************************************/
 
-void init_rpc_hdr(RPC_HDR *hdr, enum RPC_PKT_TYPE pkt_type, uint8 flags,
+void init_rpc_hdr(RPC_HDR *hdr, enum dcerpc_pkt_type pkt_type, uint8 flags,
 				uint32 call_id, int data_len, int auth_len)
 {
 	hdr->major        = 5;               /* RPC version 5 */
diff --git a/source3/rpc_server/srv_pipe_hnd.c b/source3/rpc_server/srv_pipe_hnd.c
index 2f3d763..b13e34b 100644
--- a/source3/rpc_server/srv_pipe_hnd.c
+++ b/source3/rpc_server/srv_pipe_hnd.c
@@ -264,7 +264,7 @@ static ssize_t unmarshall_rpc_header(pipes_struct *p)
 		 * AS/U doesn't set FIRST flag in a BIND packet it seems.
 		 */
 
-		if ((p->hdr.pkt_type == RPC_REQUEST) && !(p->hdr.flags & RPC_FLG_FIRST)) {
+		if ((p->hdr.pkt_type == DCERPC_PKT_REQUEST) && !(p->hdr.flags & DCERPC_PFC_FLAG_FIRST)) {
 			/*
 			 * Ensure that the FIRST flag is set. If not then we have
 			 * a stream missmatch.
@@ -444,7 +444,7 @@ static bool process_request_pdu(pipes_struct *p, prs_struct *rpc_in_p)
 		return False;
 	}
 
-	if(p->hdr.flags & RPC_FLG_LAST) {
+	if(p->hdr.flags & DCERPC_PFC_FLAG_LAST) {
 		bool ret = False;
 		/*
 		 * Ok - we finally have a complete RPC stream.
@@ -534,35 +534,35 @@ static void process_complete_pdu(pipes_struct *p)
 			(unsigned int)p->hdr.pkt_type ));
 
 	switch (p->hdr.pkt_type) {
-		case RPC_REQUEST:
+		case DCERPC_PKT_REQUEST:
 			reply = process_request_pdu(p, &rpc_in);
 			break;
 
-		case RPC_PING: /* CL request - ignore... */
+		case DCERPC_PKT_PING: /* CL request - ignore... */
 			DEBUG(0,("process_complete_pdu: Error. Connectionless packet type %u received on pipe %s.\n",
 				(unsigned int)p->hdr.pkt_type,
 				get_pipe_name_from_iface(&p->syntax)));
 			break;
 
-		case RPC_RESPONSE: /* No responses here. */
-			DEBUG(0,("process_complete_pdu: Error. RPC_RESPONSE received from client on pipe %s.\n",
+		case DCERPC_PKT_RESPONSE: /* No responses here. */
+			DEBUG(0,("process_complete_pdu: Error. DCERPC_PKT_RESPONSE received from client on pipe %s.\n",
 				get_pipe_name_from_iface(&p->syntax)));
 			break;
 
-		case RPC_FAULT:
-		case RPC_WORKING: /* CL request - reply to a ping when a call in process. */
-		case RPC_NOCALL: /* CL - server reply to a ping call. */
-		case RPC_REJECT:
-		case RPC_ACK:
-		case RPC_CL_CANCEL:
-		case RPC_FACK:
-		case RPC_CANCEL_ACK:
+		case DCERPC_PKT_FAULT:
+		case DCERPC_PKT_WORKING: /* CL request - reply to a ping when a call in process. */
+		case DCERPC_PKT_NOCALL: /* CL - server reply to a ping call. */
+		case DCERPC_PKT_REJECT:
+		case DCERPC_PKT_ACK:
+		case DCERPC_PKT_CL_CANCEL:
+		case DCERPC_PKT_FACK:
+		case DCERPC_PKT_CANCEL_ACK:
 			DEBUG(0,("process_complete_pdu: Error. Connectionless packet type %u received on pipe %s.\n",
 				(unsigned int)p->hdr.pkt_type,
 				get_pipe_name_from_iface(&p->syntax)));
 			break;
 
-		case RPC_BIND:


diff --git a/source3/rpc_server/srv_pipe.c b/source3/rpc_server/srv_pipe.c
index 040831c..1bd170f 100644
--- a/source3/rpc_server/srv_pipe.c
+++ b/source3/rpc_server/srv_pipe.c
@@ -84,11 +84,11 @@ static bool create_next_pdu_ntlmssp(pipes_struct *p)
 	memset((char *)&hdr_resp, '\0', sizeof(hdr_resp));
 
 	/* Change the incoming request header to a response. */
-	p->hdr.pkt_type = RPC_RESPONSE;
+	p->hdr.pkt_type = DCERPC_PKT_RESPONSE;
 
 	/* Set up rpc header flags. */
 	if (p->out_data.data_sent_length == 0) {
-		p->hdr.flags = RPC_FLG_FIRST;
+		p->hdr.flags = DCERPC_PFC_FLAG_FIRST;
 	} else {
 		p->hdr.flags = 0;
 	}
@@ -130,7 +130,7 @@ static bool create_next_pdu_ntlmssp(pipes_struct *p)
 	 */
 
 	if(p->out_data.data_sent_length + data_len >= prs_offset(&p->out_data.rdata)) {
-		p->hdr.flags |= RPC_FLG_LAST;
+		p->hdr.flags |= DCERPC_PFC_FLAG_LAST;
 		if (data_len_left % 8) {
 			ss_padding_len = 8 - (data_len_left % 8);
 			DEBUG(10,("create_next_pdu_ntlmssp: adding sign/seal padding of %u\n",
@@ -302,11 +302,11 @@ static bool create_next_pdu_schannel(pipes_struct *p)
 	memset((char *)&hdr_resp, '\0', sizeof(hdr_resp));
 
 	/* Change the incoming request header to a response. */
-	p->hdr.pkt_type = RPC_RESPONSE;
+	p->hdr.pkt_type = DCERPC_PKT_RESPONSE;
 
 	/* Set up rpc header flags. */
 	if (p->out_data.data_sent_length == 0) {
-		p->hdr.flags = RPC_FLG_FIRST;
+		p->hdr.flags = DCERPC_PFC_FLAG_FIRST;
 	} else {
 		p->hdr.flags = 0;
 	}
@@ -349,7 +349,7 @@ static bool create_next_pdu_schannel(pipes_struct *p)
 	 */
 
 	if(p->out_data.data_sent_length + data_len >= prs_offset(&p->out_data.rdata)) {
-		p->hdr.flags |= RPC_FLG_LAST;
+		p->hdr.flags |= DCERPC_PFC_FLAG_LAST;
 		if (data_len_left % 8) {
 			ss_padding_len = 8 - (data_len_left % 8);
 			DEBUG(10,("create_next_pdu_schannel: adding sign/seal padding of %u\n",
@@ -501,11 +501,11 @@ static bool create_next_pdu_noauth(pipes_struct *p)
 	memset((char *)&hdr_resp, '\0', sizeof(hdr_resp));
 
 	/* Change the incoming request header to a response. */
-	p->hdr.pkt_type = RPC_RESPONSE;
+	p->hdr.pkt_type = DCERPC_PKT_RESPONSE;
 
 	/* Set up rpc header flags. */
 	if (p->out_data.data_sent_length == 0) {
-		p->hdr.flags = RPC_FLG_FIRST;
+		p->hdr.flags = DCERPC_PFC_FLAG_FIRST;
 	} else {
 		p->hdr.flags = 0;
 	}
@@ -547,7 +547,7 @@ static bool create_next_pdu_noauth(pipes_struct *p)
 	 */
 
 	if(p->out_data.data_sent_length + data_len >= prs_offset(&p->out_data.rdata)) {
-		p->hdr.flags |= RPC_FLG_LAST;
+		p->hdr.flags |= DCERPC_PFC_FLAG_LAST;
 	}
 
 	/*
@@ -826,7 +826,7 @@ static bool setup_bind_nak(pipes_struct *p)
 	 * Initialize a bind_nak header.
 	 */
 
-	init_rpc_hdr(&nak_hdr, RPC_BINDNACK, RPC_FLG_FIRST | RPC_FLG_LAST,
+	init_rpc_hdr(&nak_hdr, DCERPC_PKT_BIND_NAK, DCERPC_PFC_FLAG_FIRST | DCERPC_PFC_FLAG_LAST,
 		p->hdr.call_id, RPC_HEADER_LEN + sizeof(uint16), 0);
 
 	/*
@@ -886,7 +886,7 @@ bool setup_fault_pdu(pipes_struct *p, NTSTATUS status)
 	 * Initialize a fault header.
 	 */
 
-	init_rpc_hdr(&fault_hdr, RPC_FAULT, RPC_FLG_FIRST | RPC_FLG_LAST | RPC_FLG_NOCALL,
+	init_rpc_hdr(&fault_hdr, DCERPC_PKT_FAULT, DCERPC_PFC_FLAG_FIRST | DCERPC_PFC_FLAG_LAST | DCERPC_PFC_FLAG_DID_NOT_EXECUTE,
             p->hdr.call_id, RPC_HEADER_LEN + RPC_HDR_RESP_LEN + RPC_HDR_FAULT_LEN, 0);
 
 	/*
@@ -953,7 +953,7 @@ bool setup_cancel_ack_reply(pipes_struct *p, prs_struct *rpc_in_p)
 	 * Initialize a cancel_ack header.
 	 */
 
-	init_rpc_hdr(&ack_reply_hdr, RPC_CANCEL_ACK, RPC_FLG_FIRST | RPC_FLG_LAST,
+	init_rpc_hdr(&ack_reply_hdr, DCERPC_PKT_CANCEL_ACK, DCERPC_PFC_FLAG_FIRST | DCERPC_PFC_FLAG_LAST,
 			p->hdr.call_id, RPC_HEADER_LEN, 0);
 
 	/*
@@ -1547,7 +1547,7 @@ static bool pipe_ntlmssp_auth_bind(pipes_struct *p, prs_struct *rpc_in_p,
 
 	DEBUG(10,("pipe_ntlmssp_auth_bind: NTLMSSP auth started\n"));
 
 	/* We can't set pipe_bound True yet - we need an RPC_AUTH3 response packet... */
 	return True;
 
   err:
@@ -1798,7 +1798,7 @@ bool api_pipe_bind_req(pipes_struct *p, prs_struct *rpc_in_p)
 		auth_len = prs_offset(&out_auth) - RPC_HDR_AUTH_LEN;
 	}
 
-	init_rpc_hdr(&p->hdr, RPC_BINDACK, RPC_FLG_FIRST | RPC_FLG_LAST,
+	init_rpc_hdr(&p->hdr, DCERPC_PKT_BIND_ACK, DCERPC_PFC_FLAG_FIRST | DCERPC_PFC_FLAG_LAST,
 			p->hdr.call_id,
 			RPC_HEADER_LEN + prs_offset(&out_hdr_ba) + prs_offset(&out_auth),
 			auth_len);
@@ -1986,7 +1986,7 @@ bool api_pipe_alter_context(pipes_struct *p, prs_struct *rpc_in_p)
 		auth_len = prs_offset(&out_auth) - RPC_HDR_AUTH_LEN;
 	}
 
-	init_rpc_hdr(&p->hdr, RPC_ALTCONTRESP, RPC_FLG_FIRST | RPC_FLG_LAST,
+	init_rpc_hdr(&p->hdr, DCERPC_PKT_ALTER_RESP, DCERPC_PFC_FLAG_FIRST | DCERPC_PFC_FLAG_LAST,
 			p->hdr.call_id,
 			RPC_HEADER_LEN + prs_offset(&out_hdr_ba) + prs_offset(&out_auth),
 			auth_len);
@@ -1547,7 +1547,7 @@ static bool pipe_ntlmssp_auth_bind(pipes_struct *p, prs_struct *rpc_in_p,
 	DEBUG(10,("pipe_ntlmssp_auth_bind: NTLMSSP auth started\n"));
 
-	/* We can't set pipe_bound True yet - we need an RPC_AUTH3 response packet... */
+	/* We can't set pipe_bound True yet - we need an DCERPC_PKT_AUTH3 response packet... */
 	return True;
 
-- 
Samba Shared Repository


More information about the samba-cvs mailing list